@@ -400,13 +400,13 @@ class StreamChatAsync(StreamChatInterface):
         data = {"sqs_key": sqs_key, "sqs_secret": sqs_secret, "sqs_url": sqs_url}
         return await self.post("check_sqs", data=data)
 
-    async def get_permission(self, name):
+    async def get_permission(self, id):
         """
         Get the definition for a permission
 
-        :param name: Name of the permission
+        :param id: ID of the permission
         """
-        return await self.get(f"custom_permission/{name}")
+        return await self.get(f"permissions/{id}")
 
     async def create_permission(self, permission):
         """
@@ -414,30 +414,30 @@ class StreamChatAsync(StreamChatInterface):
 
         :param permission: Definition of the permission
         """
-        return await self.post("custom_permission", data=permission)
+        return await self.post("permissions", data=permission)
 
-    async def update_permission(self, name, permission):
+    async def update_permission(self, id, permission):
         """
         Update a custom permission
 
-        :param name: Name of the permission
+        :param id: ID of the permission
         :param permission: New definition of the permission
         """
-        return await self.post(f"custom_permission/{name}", data=permission)
+        return await self.put(f"permissions/{id}", data=permission)
 
-    async def delete_permission(self, name):
+    async def delete_permission(self, id):
         """
         Delete a custom permission
 
-        :param name: Name of the permission
+        :param id: ID of the permission
         """
-        return await self.delete(f"custom_permission/{name}")
+        return await self.delete(f"permissions/{id}")
 
     async def list_permissions(self):
         """
-        List custom permissions of the app
+        List all permissions of the app
         """
-        return await self.get("custom_permission")
+        return await self.get("permissions")
 
     async def create_role(self, name):
         """
@@ -445,7 +445,7 @@ class StreamChatAsync(StreamChatInterface):
 
         :param name: Name of the role
         """
-        return await self.post("custom_role", data={"name": name})
+        return await self.post("roles", data={"name": name})
 
     async def delete_role(self, name):
         """
@@ -453,13 +453,99 @@ class StreamChatAsync(StreamChatInterface):
 
         :param name: Name of the role
         """
-        return await self.delete(f"custom_role/{name}")
+        return await self.delete(f"roles/{name}")
 
     async def list_roles(self):
         """
-        List custom roles of the app
+        List all roles of the app
         """
-        return await self.get("custom_role")
+        return await self.get("roles")
+
+    async def create_segment(self, segment):
+        """
+        Create a segment
+        """
+        return await self.post("segments", data={"segment": segment})
+
+    async def get_segment(self, segment_id):
+        """
+        Get a segment by id
+        """
+        return await self.get(f"segments/{segment_id}")
+
+    async def list_segments(self, **params):
+        """
+        List segments
+        """
+        return await self.get("segments", params)
+
+    async def update_segment(self, segment_id, data):
+        """
+        Update a segment by id
+        """
+        return await self.put(f"segments/{segment_id}", data=data)
+
+    async def delete_segment(self, segment_id):
+        """
+        Delete a segment by id
+        """
+        return await self.delete(f"segments/{segment_id}")
+
+    async def create_campaign(self, campaign):
+        """
+        Create a campaign
+        """
+        return await self.post("campaigns", data={"campaign": campaign})
+
+    async def get_campaign(self, campaign_id):
+        """
+        Get a campaign by id
+        """
+        return await self.get(f"campaigns/{campaign_id}")
+
+    async def list_campaigns(self, **params):
+        """
+        List campaigns
+        """
+        return await self.get("campaigns", params)
+
+    async def update_campaign(self, campaign_id, data):
+        """
+        Update a campaign
+        """
+        return await self.put(f"campaigns/{campaign_id}", data=data)
+
+    async def delete_campaign(self, campaign_id):
+        """
+        Delete a campaign by id
+        """
+        return await self.delete(f"campaigns/{campaign_id}")
+
+    async def schedule_campaign(self, campaign_id, send_at=None):
+        """
+        Schedule a campaign at given time
+        """
+        return await self.patch(
+            f"campaigns/{campaign_id}/schedule", data={"send_at": send_at}
+        )
+
+    async def stop_campaign(self, campaign_id):
+        """
+        Stop a in progress campaign
+        """
+        return await self.patch(f"campaigns/{campaign_id}/stop")
+
+    async def resume_campaign(self, campaign_id):
+        """
+        Resume a stopped campaign
+        """
+        return await self.patch(f"campaigns/{campaign_id}/resume")
+
+    async def test_campaign(self, campaign_id, users):
+        """
+        Trigger a test send of the given campaing to given users
+        """
+        return await self.post(f"campaigns/{campaign_id}/test", data={"users": users})
 
     async def revoke_tokens(self, before):
         """
