@@ -18,8 +18,14 @@ class ChannelInterface(abc.ABC):
             raise StreamChannelException("channel does not have an id")
         return f"channels/{self.channel_type}/{self.id}"
 
+    @property
+    def cid(self):
+        if self.id is None:
+            raise StreamChannelException("channel does not have an id")
+        return f"{self.channel_type}:{self.id}"
+
     @abc.abstractmethod
-    def send_message(self, message, user_id):
+    def send_message(self, message, user_id, **options):
         """
         Send a message to this channel
 
@@ -277,6 +283,14 @@ class ChannelInterface(abc.ABC):
     def show(self, user_id):
         pass
 
+    @abc.abstractmethod
+    def mute(self, user_id, expiration=None):
+        pass
+
+    @abc.abstractmethod
+    def unmute(self, user_id):
+        pass
+
 
 def add_user_id(payload, user_id):
     return {**payload, "user": {"id": user_id}}
