@@ -319,8 +319,12 @@ class StreamChat(StreamChatInterface):
         }
         parts = urlparse(url)
         if parts[0] == "":
-            url = "file://" + url
-        content = urlopen(Request(url, headers={"User-Agent": "Mozilla/5.0"})).read()
+            with open(url, "rb") as f:
+                content = f.read()
+        else:
+            content = urlopen(
+                Request(url, headers={"User-Agent": "Mozilla/5.0"})
+            ).read()
         response = requests.post(
             f"{self.base_url}/{uri}",
             params=self.get_default_params(),
@@ -388,13 +392,13 @@ class StreamChat(StreamChatInterface):
         data = {"sqs_key": sqs_key, "sqs_secret": sqs_secret, "sqs_url": sqs_url}
         return self.post("check_sqs", data=data)
 
-    def get_permission(self, name):
+    def get_permission(self, id):
         """
         Get the definition for a permission
 
-        :param name: Name of the permission
+        :param id: ID of the permission
         """
-        return self.get(f"custom_permission/{name}")
+        return self.get(f"permissions/{id}")
 
     def create_permission(self, permission):
         """
@@ -402,30 +406,30 @@ class StreamChat(StreamChatInterface):
 
         :param permission: Definition of the permission
         """
-        return self.post("custom_permission", data=permission)
+        return self.post("permissions", data=permission)
 
-    def update_permission(self, name, permission):
+    def update_permission(self, id, permission):
         """
         Update a custom permission
 
-        :param name: Name of the permission
+        :param id: ID of the permission
         :param permission: New definition of the permission
         """
-        return self.post(f"custom_permission/{name}", data=permission)
+        return self.put(f"permissions/{id}", data=permission)
 
-    def delete_permission(self, name):
+    def delete_permission(self, id):
         """
         Delete a custom permission
 
-        :param name: Name of the permission
+        :param id: ID of the permission
         """
-        return self.delete(f"custom_permission/{name}")
+        return self.delete(f"permissions/{id}")
 
     def list_permissions(self):
         """
         List custom permissions of the app
         """
-        return self.get("custom_permission")
+        return self.get("permissions")
 
     def create_role(self, name):
         """
@@ -433,7 +437,7 @@ class StreamChat(StreamChatInterface):
 
         :param name: Name of the role
         """
-        return self.post("custom_role", data={"name": name})
+        return self.post("roles", data={"name": name})
 
     def delete_role(self, name):
         """
@@ -441,13 +445,99 @@ class StreamChat(StreamChatInterface):
 
         :param name: Name of the role
         """
-        return self.delete(f"custom_role/{name}")
+        return self.delete(f"roles/{name}")
 
     def list_roles(self):
         """
-        List custom roles of the app
+        List all roles of the app
         """
-        return self.get("custom_role")
+        return self.get("roles")
+
+    def create_segment(self, segment):
+        """
+        Create a segment
+        """
+        return self.post("segments", data={"segment": segment})
+
+    def get_segment(self, segment_id):
+        """
+        Get a segment by id
+        """
+        return self.get(f"segments/{segment_id}")
+
+    def list_segments(self, **params):
+        """
+        List segments
+        """
+        return self.get("segments", params)
+
+    def update_segment(self, segment_id, data):
+        """
+        Update a segment by id
+        """
+        return self.put(f"segments/{segment_id}", data=data)
+
+    def delete_segment(self, segment_id):
+        """
+        Delete a segment by id
+        """
+        return self.delete(f"segments/{segment_id}")
+
+    def create_campaign(self, campaign):
+        """
+        Create a campaign
+        """
+        return self.post("campaigns", data={"campaign": campaign})
+
+    def get_campaign(self, campaign_id):
+        """
+        Get a campaign by id
+        """
+        return self.get(f"campaigns/{campaign_id}")
+
+    def list_campaigns(self, **params):
+        """
+        List campaigns
+        """
+        return self.get("campaigns", params)
+
+    def update_campaign(self, campaign_id, data):
+        """
+        Update a campaign
+        """
+        return self.put(f"campaigns/{campaign_id}", data=data)
+
+    def delete_campaign(self, campaign_id):
+        """
+        Delete a campaign by id
+        """
+        return self.delete(f"campaigns/{campaign_id}")
+
+    def schedule_campaign(self, campaign_id, send_at=None):
+        """
+        Schedule a campaign at given time
+        """
+        return self.patch(
+            f"campaigns/{campaign_id}/schedule", data={"send_at": send_at}
+        )
+
+    def stop_campaign(self, campaign_id):
+        """
+        Stop a in progress campaign
+        """
+        return self.patch(f"campaigns/{campaign_id}/stop")
+
+    def resume_campaign(self, campaign_id):
+        """
+        Resume a stopped campaign
+        """
+        return self.patch(f"campaigns/{campaign_id}/resume")
+
+    def test_campaign(self, campaign_id, users):
+        """
+        Trigger a test send of the given campaing to given users
+        """
+        return self.post(f"campaigns/{campaign_id}/test", data={"users": users})
 
     def revoke_tokens(self, before):
         """
